@@ -1744,6 +1744,8 @@ def _print_endpoints( message ):
 
 def _print_data( message ):
     for dr in message.data:
+        print("data:",dr)
+
         click.echo( "{:<15}{:<50}".format('ID: ', dr.id))
         click.echo( "{:<15}{:<50}".format('Alias: ', dr.alias if dr.alias else "(none)" ))
         _wrap_text( dr.title, "Title:", 15 )
@@ -2262,7 +2264,7 @@ def _initialize( opts ):
         _capi = CommandLib.API( opts )
 
         if _interactive and _capi._mapi.new_client_avail:
-            click.echo("Note: Your DataFed python package is out of date.")
+            click.echo(">>>> A newer DataFed client ({}) is available <<<<".format( _capi._mapi.new_client_avail ))
 
         if man_auth or _capi.getAuthUser() == None:
             if not man_auth:
